Module context

Module context 

Structs

PluginContext
Per-plugin, per-invocation execution context.
PluginContextTable
Threaded execution state carried from one hook invocation to the next within a single request lifecycle (e.g., pre_invokepost_invoke).